package ch.rakudave.jnetmap.controller.command;

import ch.rakudave.jnetmap.util.logging.Logger;


/**
 * @author rakudave
 */
public final class CommandHistory {
	protected Command[] array;
	protected int head, tail, current;
	private boolean undoable, saved = true;
	
	public CommandHistory() {
		this(20);
	}
	
	public CommandHistory(int size) {
		array = new Command[size];
		undoable = false;
	}
	
	public int decrement(int i) { //changed from private for testing
		return --i % array.length;
	}
	
	/**
	 * Adds and executes a Command to this history
	 * @param c the command to add/execute
	 * @return an optional Object from the Command
	 * @see Command
	 */
	public Object execute(Command c) {
		if (current != head) head = current;
		int temp = increment(head);
		if (temp == tail) tail = increment(tail);
		head = temp; 
		current = temp;
		array[temp] = c;
		saved = false;
		try {
			return c.redo();
		} catch(Exception e) {
			Logger.error("Unable to execute command", e);
			return null;
		} finally {
			undoable = true;
		}
	}
	
	public int increment(int i) {//changed from private for testing
		return ++i % array.length;
	}
	
	/**
	 * Re-does the previously undone Command
	 * @return an optional Object from the Command
	 */
	public Object redo() {
		if (!canRedo()) return null;
		current = increment(current);
		saved = false;
		try {
			return array[current].redo();
		} catch(Exception e) {
			Logger.error("Unable to redo command", e);
			return null;
		} finally {			
			undoable = true;
		}
	}
	
	public boolean canRedo() {
		return current != head;
	}
	
	/**
	 * Un-does the previously executed Command
	 * @return an optional Object from the Command
	 */
	public void undo() {
		if (!canUndo()) return;
		saved = false;
		try {
			array[current].undo();
		} catch(Exception e) {
			Logger.error("Unable to undo command", e);
		}
		if (current == tail) {
			undoable = false;
		} else {
			current = decrement(current);
		}
	}
	
	public boolean canUndo() {
		return undoable;
	}
	
	public void setSaved(boolean b) {
		saved = b;
	}
	
	public boolean isSaved() {
		return saved;
	}
}

