package ch.rakudave.jnetmap.view.components;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Toolkit;

import javax.swing.ImageIcon;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JProgressBar;

/**
 * Shows a borderless window containing an image and a progress-bar
 * @author rakudave
 */
public class SplashScreen {
	private static JFrame frame;
	private static JProgressBar progress;
		
    @SuppressWarnings("serial")
	public static void create() {
    	if (frame != null) return;
        final JLabel l = new JLabel(new ImageIcon(SplashScreen.class.getResource("/img/splash.png")));
        progress = new JProgressBar(JProgressBar.HORIZONTAL, 0, 100);
        progress.setStringPainted(true);
        final Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
        final Dimension labelSize = l.getPreferredSize();
        frame = new JFrame() {{
        	setTitle("jNetMap - loading...");
        	setIconImage(new ImageIcon(SplashScreen.class.getResource("/icons/Tango/jnetmap.png")).getImage());
	        setResizable(false);
	        setEnabled(false);
	        setUndecorated(true);
	        setLayout(new BorderLayout());
	        getContentPane().add(l, BorderLayout.CENTER);
	        getContentPane().add(progress, BorderLayout.SOUTH);
	        pack();
	        setLocation(screenSize.width/2 - (labelSize.width/2), screenSize.height/2 - (labelSize.height/2));
	        setVisible(true);
        }};
    }
    
    /**
     * Dispose this SplashScreen
     */
    public static void dispose() {
    	frame.dispose();
    	frame = null;
    }
    
    /**
     * Set the progress (when loading components)
     * @param percent of progress
     */
    public static void setProgress(int percent) {
    	progress.setValue(percent);
    }
    
    /**
     * Set the progress (when loading components) and an accompanying message
     * @param percent of progress
     * @param message to show
     */
    public static void setProgress(int percent, String message) {
    	setProgress(percent);
    	setProgress(message);
    }
    
    /**
     * Set the message showing in the progress-bar
     * @param message to show
     */
    public static void setProgress(String message) {
    	progress.setString(message);
    }

}
